import { defineComponent, openBlock, createElementBlock, createElementVNode, normalizeStyle, toDisplayString, watch, Fragment, renderList, createTextVNode, withModifiers, createCommentVNode } from "vue";
var _hoisted_1$4 = {
  style: {
    "width": "100px"
  }
};
function render$4(_ctx, _cache) {
  return openBlock(), createElementBlock("div", _hoisted_1$4, [createElementVNode("div", {
    class: "buttonClass",
    style: normalizeStyle(_ctx.btnStyle)
  }, toDisplayString(_ctx.label), 5)]);
}
var Button = defineComponent({
  render: render$4,
  name: "VButton",
  props: {
    label: {
      type: String
    },
    backgroundColor: {
      type: String
    },
    fontColor: {
      type: String
    },
    disabled: {
      type: Boolean
    },
    styleType: {
      type: Number
    }
  },
  computed: {
    btnStyle() {
      var bgColor = "";
      if (this.backgroundColor) {
        bgColor = "background:" + this.backgroundColor + ";";
      }
      var fontColor = "";
      if (this.fontColor) {
        fontColor = "color:" + this.fontColor + ";";
      }
      var border = "border: 1px solid #CED2D9;";
      switch (this.styleType) {
        case 1:
          bgColor = "background:#ffffff;";
          fontColor = "color:#212329;";
          break;
        case 2:
          bgColor = "background:#0074FC;";
          fontColor = "color:#ffffff;";
          border = "border: none;";
          break;
      }
      var disabled = "";
      if (this.disabled) {
        disabled = "pointer-events: none;opacity: 0.3;";
      }
      return bgColor + fontColor + disabled + border;
    }
  }
});
Button.install = function(app) {
  app.component(Button.name, Button);
};
var _hoisted_1$3 = ["checked"];
var _hoisted_2$1 = {
  class: "label"
};
function render$3(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [createElementVNode("input", {
    type: "checkbox",
    class: "checkboxClass",
    checked: _ctx.selected,
    onChange: _cache[0] || (_cache[0] = function() {
      return _ctx.changeHandler && _ctx.changeHandler(...arguments);
    })
  }, null, 40, _hoisted_1$3), createElementVNode("span", _hoisted_2$1, toDisplayString(_ctx.data.label), 1)]);
}
var Checkbox = defineComponent({
  render: render$3,
  name: "VCheckbox",
  props: {
    data: {
      type: Object
    },
    checked: {
      type: Boolean
    }
  },
  data() {
    return {
      selected: true
    };
  },
  mounted() {
    this.selected = this.checked;
  },
  methods: {
    changeHandler(e) {
      var data = {
        value: this.data.value,
        checked: e.target.checked
      };
      this.$emit("onChange", data);
    }
  }
});
Checkbox.install = function(app) {
  app.component(Checkbox.name, Checkbox);
};
var _hoisted_1$2 = ["value", "maxlength", "placeholder"];
function render$2(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [createElementVNode("input", {
    value: _ctx.value,
    type: "text",
    class: "inputClass",
    maxlength: _ctx.maxlength,
    placeholder: _ctx.placeholder,
    onInput: _cache[0] || (_cache[0] = function() {
      return _ctx.inputHandler && _ctx.inputHandler(...arguments);
    }),
    onChange: _cache[1] || (_cache[1] = function() {
      return _ctx.changeHandler && _ctx.changeHandler(...arguments);
    })
  }, null, 40, _hoisted_1$2)]);
}
var Input = defineComponent({
  render: render$2,
  name: "VInput",
  props: {
    value: {
      type: String
    },
    maxlength: {
      type: Number
    },
    placeholder: {
      type: String,
      default: "\u8BF7\u8F93\u5165\u5185\u5BB9"
    }
  },
  methods: {
    changeHandler(e) {
      this.$emit("onChange", e.target.value);
    },
    inputHandler(e) {
      this.$emit("onInput", e.target.value);
    }
  }
});
Input.install = function(app) {
  app.component(Input.name, Input);
};
var _hoisted_1$1 = ["onClick"];
var _hoisted_2 = ["onClick"];
function render$1(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [(openBlock(true), createElementBlock(Fragment, null, renderList(_ctx.list, (item, index) => {
    return openBlock(), createElementBlock("div", {
      key: index,
      style: normalizeStyle(_ctx.tabStyle(index)),
      class: "tabClass",
      onClick: ($event) => _ctx.tabClickHandler(index)
    }, [createTextVNode(toDisplayString(item.label) + " ", 1), item.canDelete != false && _ctx.select == index && _ctx.data.length > _ctx.minCount ? (openBlock(), createElementBlock("div", {
      key: 0,
      class: "deleteBtn",
      onClick: withModifiers(($event) => _ctx.deleteHandler(index), ["stop"])
    }, "\xD7", 8, _hoisted_2)) : createCommentVNode("v-if", true)], 12, _hoisted_1$1);
  }), 128)), _ctx.addable ? (openBlock(), createElementBlock("div", {
    key: 0,
    class: "addBtn",
    onClick: _cache[0] || (_cache[0] = ($event) => _ctx.addHandler()),
    style: normalizeStyle(_ctx.addBtnStyle)
  }, "+", 4)) : createCommentVNode("v-if", true)]);
}
var Tabs = defineComponent({
  render: render$1,
  name: "VTabs",
  props: {
    data: {
      type: Array
    },
    addable: {
      type: Boolean,
      default: true
    },
    maxCount: {
      type: Number,
      default: 10
    },
    minCount: {
      type: Number,
      default: 1
    }
  },
  data() {
    return {
      list: [],
      select: 0
    };
  },
  computed: {
    tabStyle() {
      return (index) => {
        if (index !== this.select) {
          return "background:#ffffff;color:#212329;";
        }
      };
    },
    addBtnStyle() {
      if (this.data.length === this.maxCount) {
        return "opacity: 0.3;pointer-events: none;";
      }
      return "";
    }
  },
  mounted() {
    this.list = this.data;
    watch(this.list, (newValue, oldValue) => {
      console.log(newValue.length, oldValue.length);
      if (this.select >= newValue.length) {
        this.select = newValue.length - 1;
      }
      this.$emit("tabChange", {
        index: this.select
      });
    });
  },
  methods: {
    tabClickHandler(index) {
      if (index === this.select) {
        return;
      }
      this.select = index;
      this.$emit("tabChange", {
        index
      });
    },
    deleteHandler(index) {
      this.$emit("deleteTab", {
        index
      });
    },
    addHandler() {
      this.$emit("addTab");
    }
  }
});
Tabs.install = function(app) {
  app.component(Tabs.name, Tabs);
};
var _hoisted_1 = ["value", "maxlength", "rows", "placeholder"];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [createElementVNode("textarea", {
    value: _ctx.value,
    class: "inputClass",
    maxlength: _ctx.maxlength,
    rows: _ctx.rows,
    placeholder: _ctx.placeholder,
    onInput: _cache[0] || (_cache[0] = function() {
      return _ctx.inputHandler && _ctx.inputHandler(...arguments);
    }),
    onChange: _cache[1] || (_cache[1] = function() {
      return _ctx.changeHandler && _ctx.changeHandler(...arguments);
    })
  }, "\n    ", 40, _hoisted_1)]);
}
var Textarea = defineComponent({
  render,
  name: "VTextarea",
  props: {
    value: {
      type: String
    },
    placeholder: {
      type: String,
      default: "\u8BF7\u8F93\u5165\u5185\u5BB9"
    },
    maxlength: {
      type: Number
    },
    rows: {
      type: Number,
      default: 3
    }
  },
  methods: {
    changeHandler(e) {
      this.$emit("onChange", e.target.value);
    },
    inputHandler(e) {
      this.$emit("onInput", e.target.value);
    }
  }
});
Textarea.install = function(app) {
  app.component(Textarea.name, Textarea);
};
var ButtonSfc = "";
var CheckboxSfc = "";
var InputSfc = "";
var TabsSfc = "";
var TextareaSfc = "";
function install(app) {
  Button.install && app.use(Button);
  Checkbox.install && app.use(Checkbox);
  Input.install && app.use(Input);
  Tabs.install && app.use(Tabs);
  Textarea.install && app.use(Textarea);
}
var umdIndex = {
  install,
  Button,
  Checkbox,
  Input,
  Tabs,
  Textarea
};
export { Button, Checkbox, Input, Tabs, Textarea, umdIndex as default, install };
